@@ -10,6 +10,13 @@ def register():
         return wrapped_f
     return wrapped
 
+def assignOrder(order):
+  @decorator
+  def do_assignment(to_func):
+    to_func.order = order
+    return to_func
+  return do_assignment
+
 @register()
 def OutputMethodMetadata(method):
     '''Outputs the stored metadata for the given method object'''
